@@ -14,7 +14,8 @@ add_columns <- function(gene_df2,
         gene_df2$input_gene <- input_dict[genes2]
     } 
     #### Add input_gene_standard col ####
-    if (standardise_genes) {
+    if (as.logical(standardise_genes) && 
+        ("input_gene_standard" %in% colnames(gene_map))) {
         messager("Adding input_gene_standard col to gene_df.", v = verbose)
         std_dict <- stats::setNames(
             gene_map$input_gene_standard,
